SystemOrganization addCategory: #'SeasideLocalisation-Test-Core'!

TestCase subclass: #SLTransaltionProxyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideLocalisation-Test-Core'!

!SLTransaltionProxyTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:12'!
testDomainDependsOnCallerCategory
	| s originalCategory |
	originalCategory := self class category.
	TextDomainManager registerClass: self class name domain: 'SeasideLocalisation-Test'.
	s := 'yksi' translate.
	[ 
	SLTransaltionTestUtils
		withTranslatorForLocaleCalled: 'en'
		inDomain: 'SeasideLocalisation-Test2'
		translating: {('yksi' -> 'one')}
		do: [ 
			SLTransaltionTestUtils
				withTranslatorForLocaleCalled: 'en'
				inDomain: 'SeasideLocalisation-Test'
				translating: {(('yksi') -> '0n3')}
				do: [ 
					self translationOf: s inLocaleCalled: 'en' shouldBe: '0n3'. ] ] ]
		ensure: [ self class category: originalCategory ]! !

!SLTransaltionProxyTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:16'!
testTranslationIsDoneWithValueOfCurrentLocale
	| s |
	s := 'yksi' translate.
	self
		withTranslatorForLocaleCalled: 'en'
		translating: {('yksi' -> 'one')}
		do: [ 
			self
				withTranslatorForLocaleCalled: 'sv'
				translating: {('yksi' -> 'ett')}
				do: [ 
					self translationOf: s inLocaleCalled: 'en' shouldBe: 'one'.
					self translationOf: s inLocaleCalled: 'sv' shouldBe: 'ett' ] ]! !

!SLTransaltionProxyTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:14'!
translationOf: anObject inLocaleCalled: aLocaleName shouldBe: expectedString
	^SLCurrentLocale use: (SLTransaltionTestUtils localeFor: aLocaleName) during: [ self should: expectedString = anObject asString ]! !

!SLTransaltionProxyTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:16'!
withTranslatorForLocaleCalled: aByteString translating: anArray do: aBlockClosure 
	SLTransaltionTestUtils withTranslatorForLocaleCalled: aByteString translating: anArray do: aBlockClosure.! !

WtUnitTestComponentSeleniumCase subclass: #SLSelectLocaleComponentTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideLocalisation-Test-Core'!

!SLSelectLocaleComponentTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 13:52'!
currentLocaleName
	^Locale current localeID asString select: [ :c | c isAlphaNumeric or: [ c = $- ] ].
	"There is bug in linux Locale plugin that returns 0 character after localeID"! !

!SLSelectLocaleComponentTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 13:55'!
localeSelect 
	^self comboBox: 'localeSelect'.! !

!SLSelectLocaleComponentTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 14:24'!
localeWithLang: lang andCountry: country
	^ Locale new localeID: (LocaleID isoLanguage: lang isoCountry: country)! !

!SLSelectLocaleComponentTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:08'!
selectLocale: aString
	self localeSelect select: aString.
	(self buttonByValue: 'Change locale') click waitForPageToLoad! !

!SLSelectLocaleComponentTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:28'!
setUp
	| localeSelect |
	super setUp.
	localeSelect := SLLocaleTestComponent new.
	"Muutetaan siten, ett laitetaan kntjt jos tss valmiiksi ja 
	komponentti tarkistaa olemassa olevat knnkset ja listaa localet
	sen perusteella. Tllin tietysti tearDown."
	localeSelect localeSelect
		availableLocales:
			(Array
				with: (self localeWithLang: 'fi' andCountry: 'FI')
				with: (self localeWithLang: 'en' andCountry: 'EN')
				with: (self localeWithLang: 'sv' andCountry: 'SV')).
	localeSelect testObject: 'teksti' translate.
	self initComponent: [ localeSelect ].
	self openUrl: self componentUrl! !

!SLSelectLocaleComponentTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:22'!
testEnTranslationIsFound
	SLTransaltionTestUtils
		withTranslatorForLocaleCalled: 'en'
		translating: {('teksti' -> 'some text')}
		do: [ 
			self selectLocale: 'en-EN'.
			self should: (self isTextPresent: 'some text') ]! !

!SLSelectLocaleComponentTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:29'!
testFiTranslationIsFound
	SLTransaltionTestUtils
		withTranslatorForLocaleCalled: 'fi'
		translating: {('teksti' -> 'teksti')}
		do: [ 
			self selectLocale: 'fi-FI'.
			self should: (self isTextPresent: 'teksti') ]! !

!SLSelectLocaleComponentTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:17'!
testLocaleCanBeChanged
	| options |
	options := self localeSelect selectOptions.
	self should: options first = 'fi-FI'.
	self should: options second = 'en-EN'.
	self should: options third = 'sv-SV'.
	self selectLocale: 'en-EN'.
	self should: (self isTextPresent: 'Current locale is en-EN')! !

!SLSelectLocaleComponentTest methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:03'!
testLocalePrintedOutAndSelectIsPresent
	self should: self localeSelect isPresent.
	self should: (self isTextPresent: 'Current locale is ', self currentLocaleName).! !

Object subclass: #SLDummyTranslator
	instanceVariableNames: 'translations domain'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideLocalisation-Test-Core'!

!SLDummyTranslator methodsFor: 'accessing' stamp: 'IlariLiukko 12/19/2011 13:02'!
domain
	^ domain! !

!SLDummyTranslator methodsFor: 'accessing' stamp: 'IlariLiukko 12/19/2011 13:02'!
domain: anObject
	domain := anObject! !

!SLDummyTranslator methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/19/2011 12:38'!
translate: aString
	^ self translate: aString inDomain: nil.! !

!SLDummyTranslator methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/19/2011 13:19'!
translate: aString inDomain: aDomainName
	^ (self domain isNil or: [ aDomainName = self domain ])
		ifTrue: [ self translations at: aString ifAbsent: [ aString ] ]
		ifFalse: [ aString ]! !

!SLDummyTranslator methodsFor: 'accessing' stamp: 'IlariLiukko 12/19/2011 12:05'!
translations
	^ translations! !

!SLDummyTranslator methodsFor: 'accessing' stamp: 'IlariLiukko 12/19/2011 12:05'!
translations: anObject
	translations := anObject! !

Object subclass: #SLTransaltionTestUtils
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideLocalisation-Test-Core'!

!SLTransaltionTestUtils class methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:12'!
localeFor: aString
	^ aString isString
		ifTrue: [ Locale localeID: (LocaleID isoString: aString) ]
		ifFalse: [ aString ]! !

!SLTransaltionTestUtils class methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:11'!
withTranslatorForLocaleCalled: aLocaleName inDomain: aDomainName translating: dictionary do: aBlock
	| oldTranslator locale |
	locale := self localeFor: aLocaleName.
	oldTranslator := NaturalLanguageTranslator translators at: locale localeID ifAbsent: [ nil ].
	NaturalLanguageTranslator translators
		at: locale localeID
		put:
			(SLDummyTranslator new
				domain: aDomainName;
				translations: (dictionary asDictionary);
				yourself).
	aBlock
		ensure: [ NaturalLanguageTranslator translators at: locale localeID put: oldTranslator ]! !

!SLTransaltionTestUtils class methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:11'!
withTranslatorForLocaleCalled: aLocaleName translating: dictionary do: aBlock
	^ self
		withTranslatorForLocaleCalled: aLocaleName
		inDomain: nil
		translating: dictionary
		do: aBlock! !

WAComponent subclass: #SLLocaleTestComponent
	instanceVariableNames: 'localeSelect testObject'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideLocalisation-Test-Core'!

!SLLocaleTestComponent methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/19/2011 15:46'!
initialize
	super initialize.
	localeSelect := SLSelectLocaleComponent new.! !

!SLLocaleTestComponent methodsFor: 'accessing' stamp: 'IlariLiukko 12/21/2011 14:20'!
localeSelect
	^ localeSelect! !

!SLLocaleTestComponent methodsFor: 'as yet unclassified' stamp: 'IlariLiukko 12/21/2011 15:05'!
renderContentOn: html
	html
		form: [ 
			html render: localeSelect.
			html submitButton with: 'Change locale' ].
	html horizontalRule.
	html
		paragraph: [ 
			html
				text: 'Current locale is ';
				text: SLCurrentLocale value localeID asString ].
	html
		div: [ 
			html render: testObject.
].			! !

!SLLocaleTestComponent methodsFor: 'accessing' stamp: 'IlariLiukko 12/21/2011 15:05'!
testObject
	^ testObject! !

!SLLocaleTestComponent methodsFor: 'accessing' stamp: 'IlariLiukko 12/21/2011 15:05'!
testObject: anObject
	testObject := anObject! !
